@@ -65,10 +65,9 @@ class MYSQLExporter(Result):
             print "Getting user data"
             aq= "update tw_user set tw_id=\'%s\', task_status=\'%s\', task_host=\'%s\', created_at=\'%s\', statuses_count=\'%s\', friend_count=\'%s\', followers_count=\'%s\', geo_lat=\'%s\', geo_long=\'%s\', geo_text=\'%s\' where  name=\'%s\'" ,
 
-        query=[ aq,
-                "Insert into tw_userfollower (user_tw_id, follower) values (%s,%s)",
-                "Insert into tw_frienduser (friend, user_tw_id) values (%s,%s)"
-                ]
+        query=[ "Insert into tw_userfollower (user_tw_id, follower) values (%s,%s)",
+                "Insert into tw_frienduser (friend, user_tw_id) values (%s,%s)" ]
+
         mysql=self.args.mysql.split(',') 
 
         try:
@@ -76,13 +75,14 @@ class MYSQLExporter(Result):
         except Exception, e:
             print "Not saving to mysql database: %s" %e
 
+        if self.args.get_only_ff:
+            self.save(aq, [ 2, obj[0][0] ])
+        else:
+            self.save(aq, obj[0])
         return [ [ self.save(query[o], b) for b in i ] for o, i  in enumerate(obj)]
 
     def save(self, query, args, status=True):
         try:
-            if self.args.get_only_ff:
-                args=[2, args[0]]
-                print args
             print(query %tuple(args))
             self.sqlconn.cursor().execute(query %tuple(args))
             self.sqlconn.commit()
